#!/bin/bash
###########################################################################################################################
#
# Name:         run_tests.sh
# Description:  Test script that goes through all peripheral devices on the Intel Russellville In-Vehicle Infotainment board
# Author:       Shahin Ghazinouri
# Version:      1.3
# Last changed: 2009-08-14
#
# Changelog:
# 1.0 Initial release
# 1.1 Various fixes
# 1.2 Added simple MLB test, APIX and CAN placeholders
#     Added automatic install of library needed by mplayer
#     Added helpful clues on why some test might have failed
# 1.3 Various fixes
#     Added call to MLB test application
#     Added log file generation
#     Added updated flashtool
# 1.4 Added FPGA version readout
#     Added kernel version readout
#     Added updated radio test application with mute support
#     Added automatic detection of flash base address
###########################################################################################################################
#Start by checking if we are root
if [[ $UID -ne 0 ]]; then
    echo "This script must be run as root"
    exit 1
fi

rm log.txt 2>/dev/null

printf "Intel Russellville test script V1.4\n"  | tee log.txt
printf "Copyright Mocean Laboratories AB, 2009\n" | tee -a log.txt
printf "Results will be logged to log.txt.\n"
printf "Existing log file will be overwritten.\n"
printf "\n" | tee -a log.txt
sleep 1
kernel=$(uname -a | awk '{print $3}')
printf "System info:\n" | tee -a log.txt
printf "Linux kernel version is $kernel \n" | tee -a log.txt
if [ ! -d "/sys/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/" ]
then
    printf "Error: No Timberdale FPGA device found - quitting\n" | tee -a log.txt
else
      version=$(cat /sys/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/fw_ver)
      echo "Timberdale FPGA version is $version" | tee -a log.txt
printf "Press ENTER to begin testing..."
read
printf "\n" | tee -a log.txt
#GPIO
printf "Running subsystem test 1: GPIO...\n" | tee -a log.txt
#Check if we can access GPIO
if [ ! -d "/sys/class/gpio/gpiochip0/" ]
then
    printf "Error: Unable to access GPIO\n" | tee -a log.txt
else
    printf "Found Timberdale GPIO peripheral\n" | tee -a log.txt
    #Check if gpio15 is already initialized, if not we initialize it
    #GPIO0->   GPIO
    #GPI0100-> Port Expander
    #GPIO200-> HS/LS
    if [ ! -d "/sys/class/gpio/gpio15" ]
    then
	echo 15 > /sys/class/gpio/export
    fi
    sleep 1
    echo out > /sys/class/gpio/gpio15/direction
    printf "Setting GPIO15 to 0...\n"  | tee -a log.txt
    sleep 1
    echo 0 > /sys/class/gpio/gpio15/value
    value=$(cat /sys/class/gpio/gpio15/value)
    #Write a value and read it back
    if [ $value = 1 ]
    then
	printf "Error: GPIO15 did not read back as 0\n" | tee -a log.txt
    else
	printf "Successfully read back 0 from GPIO15\n" | tee -a log.txt
	sleep 1
	echo 1 > /sys/class/gpio/gpio15/value
	printf "Setting GPIO15 to 1...\n"
	sleep 1
	echo 1 > /sys/class/gpio/gpio15/value
	value=$(cat /sys/class/gpio/gpio15/value)
	if [ $value = 1 ]
	then
	    printf "Successfully read back 1 from GPIO15\n" | tee -a log.txt
	    printf "GPIO test successful\n" | tee -a log.txt
	else
	    printf "Error: GPIO15 did not read back as 1\n" | tee -a log.txt
	fi
    fi
fi
sleep 1
printf "Press ENTER to continue..."
read
printf "\n\n" | tee -a log.txt

#SPI
printf "Running subsystem test 2: SPI...\n" | tee -a log.txt
printf "Testing Port Expander...\n" | tee -a log.txt
printf "Note: This test should fail if your hardware is configured for HS/LS switch\n"
#Check if we can access it
if [ ! -d "/sys/class/gpio/gpiochip200/" ]
then
    printf "Error: Unable to access Port Expander\n" | tee -a log.txt
    printf "Your FPGA might be configured for 8-bit SPI\n"
else
    printf "Found Port Expander GPIO device\n" | tee -a log.txt
    if [ ! -d "/sys/class/gpio/gpio200" ]
    then
	echo 200 > /sys/class/gpio/export
    fi
    sleep 1
    echo out > /sys/class/gpio/gpio200/direction
    printf "Setting Port Expander output P4 to 1 (Pin 3 on header J5)...\n" | tee -a log.txt
    sleep 1
    echo 0 > /sys/class/gpio/gpio200/value
    value=$(cat /sys/class/gpio/gpio200/value)
#Write a value and read it back
    if [ $value = 1 ]
    then
	printf "Error: Output did not read back as 0\n" | tee -a log.txt
    else
	printf "Successfully read back 0\n" | tee -a log.txt
	sleep 1
	echo 1 > /sys/class/gpio/gpio200/value
	printf "Setting Port Expander output P4 to 1 (Pin 3 on header J5)...\n" | tee -a log.txt
	sleep 1
	echo 1 > /sys/class/gpio/gpio200/value
	value=$(cat /sys/class/gpio/gpio200/value)
	if [ $value = 1 ]
	then
	    printf "Successfully read back 1\n" | tee -a log.txt
	    printf "Port Expander test successful\n" | tee -a log.txt
	else
	    printf "Error: Did not read back as 1\n" | tee -a log.txt
	fi
    fi
fi
sleep 1
printf "Press ENTER to continue..."
read
printf "\n\n" | tee -a log.txt
printf "Testing HS/LS switch..\n" | tee -a log.txt
printf "Note: This test should fail if your hardware is configured for Port Expander\n"
#Check if we can access it
if [ ! -d "/sys/class/gpio/gpiochip100/" ]
then
    printf "Error: Unable to access HS/LS switch\n" | tee -a log.txt
    printf "Your FPGA might be configured for 16-bit SPI\n"
    printf "If the Port Expander test was successful, your FPGA is configured for 16-bit SPI\n"
else
    printf "Found HS/LS GPIO device\n" | tee -a log.txt
    if [ ! -d "/sys/class/gpio/gpio100" ]
    then
	echo 100 > /sys/class/gpio/export
    fi
    sleep 1
    echo out > /sys/class/gpio/gpio100/direction
    printf "Driving HS/LS pin S1 to 12V...\n" | tee -a log.txt
    sleep 1
    echo 0 > /sys/class/gpio/gpio100/value
    
    #Ask user to check value
    printf "Measure output, it should be at 12V level\n"
    printf "Press ENTER to continue testing once correct output level has been verified...\n"
    read
    printf "Sinking HS/LS pin D1 output to GND...\n" | tee -a log.txt
    sleep 1
    echo 1 > /sys/class/gpio/gpio100/value
    printf "Measure output, it should be at GND level\n"
    printf "Press ENTER to continue testing once correct output level has been verified...\n"
    read
    printf "HS/LS test completed\n" | tee -a log.txt
fi
sleep 1
printf "Press ENTER to continue..."
read
printf "\n\n" | tee -a log.txt

#I2C
printf "Running subsystem test 3: I2C...\n" | tee -a log.txt
/sbin/modprobe i2c-dev 
if [ "./i2cdetect -y -l 2>/dev/null | grep xiic-i2c" = "" ]
then
    printf "ERROR: Xilinx I2C device not found" | tee -a log.txt
else
    sleep 1
    printf "Found Xilinx I2C device\n" | tee -a log.txt
    i2cbus=$(./i2cdetect -y -l 2>/dev/null | grep xiic-i2c | awk '{print $1}')
    bus=$( echo $i2cbus | sed -e "s/^....\(.*\)$/\1/g")
    printf "Scanning I2C bus..." | tee -a log.txt
    sleep 1
    ./i2cdetect $bus | tee -a log.txt
fi

sleep 1
printf "Press ENTER to continue..."
read
printf "\n\n" | tee -a log.txt

#HDA
printf "Running subsystem test 4: HDA... \n" | tee -a log.txt
if [ ! -c "/dev/snd/pcmC0D1p" ]
then
    if [ ! -c "/dev/snd/pcmC1D1p" ]
    then	
	printf "ERROR: No audio device found\n"  | tee -a log.txt
	printf "Make sure HDA is enabled in BIOS\n" 
    else
	if [ ! -f "/usr/lib/libXxf86dga.so.1" ]
	then
	    printf "Error: Missing library libXxf86dga, required to run mplayer\n" | tee -a log.txt
	    sleep 1
	    printf "Attempting to install from local source..."
	    yum --nogpgcheck install libXxf86dga-1.0.2-9.30.moblin2.i586.rpm
	    sleep 3
	else
	    printf ""
	fi
	./mplayer test_audio.ogg &
	sleep 3
	printf "Running mplayer to play audio..\n" | tee -a log.txt
	printf "If you have connected speakers/headphones you should now hear something\n"
    fi
else
    if [ ! -f "/usr/lib/libXxf86dga.so.1" ]
    then
	printf "Error: Missing library libXxf86dga, required to run mplayer\n" | tee -a log.txt
	sleep 1
	printf "Attempting to install from local source..."
	yum --nogpgcheck install libXxf86dga-1.0.2-9.30.moblin2.i586.rpm
	sleep 3
    else
	printf ""
    fi
    ./mplayer test_audio.ogg &
    sleep 3
    printf "Running mplayer to play audio..\n" | tee -a log.txt
    printf "If you have connected speakers/headphones you should now hear something\n"
fi

printf "Press ENTER to continue testing...\n"
read
killall -9 mplayer
sleep 1
printf "\n\n" | tee -a log.txt

#Tuner
printf "Running subsystem test 5: Tuner...\n" | tee -a log.txt
if [ ! -c "/dev/radio0" ]
then
    printf "Error: Unable to access radio\n" | tee -a log.txt
else
    printf "Found NXP Radio tuner and DSP\n" | tee -a log.txt
    sleep 1
    ./testradio | tee -a log.txt
    if [ ! -c "/dev/snd/pcmC0D1p" ]
    then
	if [ ! -c "/dev/snd/pcmC1D1p" ]
	then	
	    printf "ERROR: No audio device found\n"  | tee -a log.txt
	    printf "You will not be able to hear the tuner output\n" 
	else
	    printf "If you have speakers or headphones connected and AUX is not muted, you should now hear something.\n"
	    printf "To start the mixer, run the command 'alsamixer -c 0' in a terminal.\n"
	    printf "If there is still no sound, your Russellville board might need a hardware patch. Refer to the patch documentation.\n"
	fi
    else
	printf "If you have speakers or headphones connected and AUX is not muted, you should now hear something.\n"
	printf "To start the mixer, run the command 'alsamixer -c 0' in a terminal.\n"
	printf "If you there is still no sound, your Russellville board might need a hardware patch. Refer to the patch documentation.\n"
    fi
fi
sleep 1
printf "Press ENTER to continue..."
read
printf "\n\n" | tee -a log.txt
./testradio 999 m >&/dev/null
    

#I2S
printf "Running subsystem test 6: I2S...\n" | tee -a log.txt
if [ -c "/dev/snd/pcmC0D1p" ]
then
    if [ ! -c "/dev/snd/pcmC1D2c" ]
    then
	printf "Error: Unable to access I2S device\n" | tee -a log.txt
    else
	printf "Found Timberdale I2S device\n" | tee -a log.txt
	if [ ! -c "/dev/radio0" ]
	then
	    printf "Error: Unable to access radio, no sound source available to test I2S\n" | tee -a log.txt
	else
	    sleep 1
	    ./testradio | tee -a log.txt
	    printf "Recording 5s of sound from radio tuner...\n" | tee -a log.txt
	    arecord test.wav -c 2 -f S16_LE -r 44100 -M -D hw:1,2 & 
	    sleep 5
	    ./testradio 999 m >&/dev/null
	    killall -9 arecord
	    if [ ! -f "/usr/lib/libXxf86dga.so.1" ]
	    then
		printf "Error: Missing library libXxf86dga, required to run mplayer\n" | tee -a log.txt
		sleep 1
		printf "Attempting to install from local source..."
		yum --nogpgcheck install libXxf86dga-1.0.2-9.30.moblin2.i586.rpm
		sleep 3
	    else
		printf ""
	    fi	    
	    printf "Playing back recorded file...\n" | tee -a log.txt
	    ./mplayer test.wav & 
	    sleep 5
	    killall -9 ./mplayer
	fi
    fi
else
    if [ ! -c "/dev/snd/pcmC0D2c" ]
    then
	printf "Error: Unable to access I2S device\n" | tee -a log.txt
    else
	printf "Found Timberdale I2S device\n" | tee -a log.txt
	if [ ! -c "/dev/radio0" ]
	then
	    printf "Error: Unable to access radio, no sound source available to test I2S\n" | tee -a log.txt
	else
	    sleep 1
	    ./testradio | tee -a log.txt
	    printf "Recording 5s of sound from radio tuner...\n" | tee -a log.txt
	    arecord test.wav -c 2 -f S16_LE -r 44100 -M -D hw:0,2 & 
	    sleep 5
	    killall -9 arecord
	    printf "Playing back recorded file...\n" | tee -a log.txt
	    if [ ! -f "/usr/lib/libXxf86dga.so.1" ]
	    then
		printf "Error: Missing library libXxf86dga, required to run mplayer\n" | tee -a log.txt
		sleep 1
		printf "Attempting to install from local source..."
		yum --nogpgcheck install libXxf86dga-1.0.2-9.30.moblin2.i586.rpm
		sleep 3
	    else
		printf ""
	    fi	    
	    ./mplayer test.wav & 
	    sleep 5
	    killall -9 ./mplayer
	fi
    fi
fi
printf "Press ENTER to continue..."
read
printf "\n\n" | tee -a log.txt
#Inand
printf "Running subsystem test 7: Inand...\n" | tee -a log.txt
printf "Remove any SD cards and press ENTER\n"
read
umount /dev/mmcblk0p1 inand 2>/dev/null
umount /dev/mmcblk0 inand 2>/dev/null
#See if device exists
if [ ! -b "/dev/mmcblk0p1" ]
then
    if [ ! -b "/dev/mmcblk0" ]
    then	
	sd1=/dev/mmcblk0p1
	sd2=/dev/mmcblk0
	printf "Error: Unable to access Inand\n" | tee -a log.txt
	printf "Inand test failed\n" | tee -a log.txt
    else
    	sd1=/dev/mmcblk1p1
	sd2=/dev/mmcblk1
	mkdir inand 2>/dev/null
	mount /dev/mmcblk0 inand 2>/dev/null
	cp testfile inand/testfile
	sync
	rm newfile >/dev/null
	sync
	cp inand/testfile newfile
	sync
	checksum1=$(md5sum newfile | awk '{print $1}')
	checksum2=$(md5sum testfile| awk '{print $1}')
	if [ $checksum1 = $checksum2 ]
	then
	    printf "Test file CRC correct\n" | tee -a log.txt
	    printf "INAND test successful\n" | tee -a log.txt
	else 
	    printf "CRC failure\n" | tee -a log.txt
	fi	
    fi
else
    sd1=/dev/mmcblk1p1
    sd2=/dev/mmcblk1
    mkdir inand 2>/dev/null
    mount /dev/mmcblk0p1 inand 2>/dev/null
    cp testfile inand/testfile
    sync
    rm newfile >/dev/null
    sync
    cp inand/testfile newfile
    sync
    checksum1=$(md5sum newfile | awk '{print $1}')
    checksum2=$(md5sum testfile| awk '{print $1}')
    
    if [ $checksum1 = $checksum2 ]
    then
	printf "Test file CRC correct\n" | tee -a log.txt
	printf "SDHC test successful\n" | tee -a log.txt
    else 
	printf "CRC failure\n"
    fi
fi
umount inand 2>/dev/null
rm -rf inand 2>/dev/null
sleep 1

printf "Press ENTER to continue..."
read
printf "\n\n" | tee -a log.txt

#SDHC
printf "Running subsystem test 8: SD Slot 1...\n" | tee -a log.txt
printf "Please insert an SD card into the slot closest to the mid of the board and press ENTER...\n"
read
if [ ! -b $sd1 ]
then
    if [ ! -b $sd2 ]
    then
	printf "Error: Unable to access SD card\n" | tee -a log.txt
    else
	printf "Found SD card\n" | tee -a log.txt
	printf "Testing write and read...\n" | tee -a log.txt
	sleep 1
	mkdir sdhc 2>/dev/null
	umount $s2d 2>/dev/null
	mount $sd2 sdhc
	cp testfile sdhc/testfile
	sync
	rm newfile 2>/dev/null 
	sync
	cp sdhc/testfile newfile
	sync
	checksum1=$(md5sum newfile | awk '{print $1}')
	checksum2=$(md5sum testfile| awk '{print $1}')
	
	if [ $checksum1 = $checksum2 ]
	then
	    printf "Test file CRC correct\n" | tee -a log.txt
	    printf "SD slot 1 test successful\n" | tee -a log.txt
	else 
	    printf "CRC failure\n" | tee -a log.txt
	fi
    fi
else
    printf "Found SD card\n" | tee -a log.txt
    printf "Testing write and read...\n" | tee -a log.txt
    sleep 1
    mkdir sdhc 2>/dev/null
    umount $sd1 2>/dev/null
    mount $sd1 sdhc
    cp testfile sdhc/testfile
    sync
    rm newfile 2>/dev/null 
    sync
    cp sdhc/testfile newfile
    sync
    checksum1=$(md5sum newfile | awk '{print $1}')
    checksum2=$(md5sum testfile| awk '{print $1}')
    
    if [ $checksum1 = $checksum2 ]
    then
	printf "Test file CRC correct\n" | tee -a log.txt
	printf "SD slot 1 test successful\n" | tee -a log.txt
    else 
	printf "CRC failure\n" | tee -a log.txt
    fi
fi

umount sdhc 2>/dev/null
rm -rf sdhc 2>/dev/null
sleep 1
printf "Press ENTER to continue..."
read
printf "\n\n" | tee -a log.txt

#SD Route
printf "Running subsystem test 9: SD slot 2...\n"  | tee -a log.txt
printf "Please remove the previously inserted SD card and insert an SD card into the slot closest to the edge of the board and press ENTER...\n"
read
if [ ! -b $sd1 ]
then
    if [ ! -b $sd2 ]
    then
	printf "Error: Unable to access SD card\n" | tee -a log.txt
    else
	printf "Found SD card\n" | tee -a log.txt
	printf "Testing write and read...\n" | tee -a log.txt
	sleep 1
	mkdir sd-route 2>/dev/null
	mount $sd2 sd-route
	cp testfile sd-route/testfile
	sync
	rm newfile 2>/dev/null 
	sync
	cp sd-route/testfile newfile
	sync
	checksum1=$(md5sum newfile | awk '{print $1}')
	checksum2=$(md5sum testfile| awk '{print $1}')
	if [ $checksum1 = $checksum2 ]
	then 
	    printf "Test file CRC correct\n" | tee -a log.txt
	    printf "SD slot 2 test successful\n" | tee -a log.txt
	else 
	    printf "CRC failure\n" | tee -a log.txt
	fi
    fi
else
    printf "Found SD card\n" | tee -a log.txt
    printf "Testing write and read...\n" | tee -a log.txt
    sleep 1
    mkdir sd-route 2>/dev/null
    mount $sd1 sd-route
    cp testfile sd-route/testfile
    sync
    rm newfile 2>/dev/null 
    sync
    cp sd-route/testfile newfile
    sync
    checksum1=$(md5sum newfile | awk '{print $1}')
    checksum2=$(md5sum testfile| awk '{print $1}')
    
    if [ $checksum1 = $checksum2 ]
    then
	printf "Test file CRC correct\n" | tee -a log.txt
	printf "SD slot 2 test successful\n" | tee -a log.txt
    else 
	printf "CRC failure\n" | tee -a log.txt
    fi
fi
umount sd-route 2>/dev/null
rm -rf sd-route 2>/dev/null
sleep 1
printf "Press ENTER to continue..."
read
printf "\n\n" | tee -a log.txt

#Video in
printf "Running subsystem test 10: Video in... \n" | tee -a log.txt
if [ ! -c "/dev/video0" ]
then
    printf "Error: Unable to find video device\n" | tee -a log.txt
else
    if [ ! -f "/usr/lib/libXxf86dga.so.1" ]
    then
	printf "Error: Missing library libXxf86dga, required to run mplayer\n" | tee -a log.txt
	sleep 1
	printf "Attempting to install from local source..."
	yum --nogpgcheck install libXxf86dga-1.0.2-9.30.moblin2.i586.rpm
	sleep 3
    else
	printf ""
    fi
    ./mplayer tv:// >&/dev/null &
    sleep 5
    printf "Running mplayer to display video input...\n" | tee -a log.txt
    printf "If a video source is connected you should see it displayed\n"
    printf "Otherwise you should see a blue screen\n"
    printf "Press ENTER when done\n"
    read
    killall -9 mplayer >&/dev/null 
fi
sleep 1
printf "Press ENTER to continue..." 
read
printf "\n\n" | tee -a log.txt

#Infineon BT
printf "Running subsystem test 11: Infineon BT... \n" | tee -a log.txt
printf "Note: This test should fail if your hardware is configured for CSR BT\n"
if [ ! -c "/dev/ttyTU0" ]
then
    printf "ERROR: No BT UART port found" | tee -a log.txt
else
    printf "Testing HCI communication with Infineon chip at 115200 baud..." | tee -a log.txt
    ./hciattach_timb -s 115200 ttyTU0 timb-unistone >&/dev/null 
    hcitool scan | tee -a log.txt
    sleep 1
    killall hciattach_timb >&/dev/null
fi
printf "Press ENTER to continue..."
read
printf "\n\n" | tee -a log.txt

#CSR BT
printf "Running subsystem test 12: CSR BT... \n" | tee -a log.txt
printf "Note: This test should fail if your hardware is configured for Infineon BT\n"
if [ ! -c "/dev/ttyTU0" ]
then
    printf "ERROR: No BT UART port found" | tee -a log.txt
else
    if [ -d "/sys/class/gpio/gpio15" ]
    then
	echo out > /sys/class/gpio/gpio15/direction >&/dev/null
	printf "Toggling CSR reset pin...\n"
	echo 0 > /sys/class/gpio/gpio15/value >&/dev/null
	sleep 1
	echo 1 > /sys/class/gpio/gpio15/value >&/dev/null
	printf "CSR reset complete\n"
    fi
    printf "Testing HCI communication with CSR chip..." | tee -a log.txt
    ./bccmd -t HCI -d -dev-ttyTU0 rand | tee -a log.txt
    sleep 1
    ./bccmd -t HCI -d -dev-ttyTU0 rand | tee -a log.txt
fi
printf "Press ENTER to continue...\n"
read
printf "\n\n" | tee -a log.txt

#Ethernet
printf "Running subsystem test 13: Ethernet... \n" | tee -a log.txt

if [ "`/sbin/ifconfig |grep eth0`" = "" ]
then 
    printf "ERROR: No ethernet device found\n" | tee -a log.txt
else
    printf "Make sure you are connected to the Internet and disconnect any USB Ethernet devices\n"
    printf "Press ENTER to continue...\n"
    read
    printf "Pinging google.com...\n" | tee -a log.txt
    ping www.google.com | tee -a log.txt &
    sleep 3
    killall -9 ping
    printf "Press ENTER to continue..."
    read
fi
printf "\n\n" | tee -a log.txt

#Flash I/F
printf "Running subsystem test 14: Flash I/F... \n" | tee -a log.txt
flashbase=$(cat /proc/iomem | grep 02:00.0 | grep fffffff | awk '{print $1}' | awk 'BEGIN { FS = "-" } ; { print $1 }')
printf "Flashing FPGA config area 2 with timberdale_russelville.bin... \n" | tee -a log.txt
./timberdale_flashtool 1 0 1 timberdale_russelville.bin 0x$flashbase | tee -a log.txt
sleep 1
printf "\n\n" | tee -a log.txt

#MOST
printf "Running subsystem test 15: MOST... \n" | tee -a log.txt
if [ ! -d "/sys/bus/platform/devices/timb-most" ]
then
    printf "ERROR: No MOST bus found\n" | tee -a log.txt
else
    printf "Found Timberdale MOST bus\n" | tee -a log.txt
    sleep 1
    printf "Testing communication with INIC...\n" | tee -a log.txt
    sleep 3
    ./mlbtest | tee -a log.txt
fi
printf "Press ENTER to continue...\n"
read
printf "\n\n" 

#APIX - Placeholder for now
printf "Running subsystem test 16: APIX back-channel... \n"  | tee -a log.txt
if [ ! -c "/dev/ttyTU1" ]
then
    printf "ERROR: No APIX back-channel UART port found\n"  | tee -a log.txt
else
    printf "Found Timberdale APIX back-channel UART port found\n"  | tee -a log.txt
fi
printf "Press ENTER to continue...\n"
read
printf "\n\n"  | tee -a log.txt

#CAN - Placeholder for now
printf "Running subsystem test 17: CAN... \n" | tee -a log.txt
if [ ! -c "/dev/CAN" ]
then
    printf "ERROR: No CAN bus found\n" | tee -a log.txt
else
    printf "Found Timberdale CAN bus\n" | tee -a log.txt
fi
printf "Press ENTER to continue...\n" 
read
printf "\n\n" | tee -a log.txt


rm newfile 2>/dev/null 

#Report results
printf "All tests completed\n" | tee -a log.txt
fi

